Module: RJack
- Defined in:
- lib/rjack-logback/base.rb,
lib/rjack-logback.rb
Overview
-- Copyright (c) 2008-2017 David Kellum
rjack-logback is free software: you can redistribute it and/or modify it under the terms of either of following licenses:
GNU Lesser General Public License v3 or later
Eclipse Public License v1.0
rjack-logback is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. ++
Defined Under Namespace
Modules: Logback